// This program reads grades and weights from stdin and prints the weighted
// average grade. It stops reading when it encounters a non-number or EOF.

#include <iostream>
#include <vector>

// A weighted grade consists of the raw grade and a weight that determines
// its value relative to other grades.
struct Weighted_grade
{
    double grade;
    double weight;
};

// Reads a vector of weighted grades from cin, stopping when it encounters a
// non-number of EOF. Each weighted grade is read as the raw grade followed
// by the weight.
std::vector<Weighted_grade> read_grades()
{
    std::vector<Weighted_grade> result;
    Weighted_grade wg;

    while (std::cin >> wg.grade && std::cin >> wg.weight) {
        result.push_back(wg);
    }

    return result;
}

// Computes the weighted sum of a vector of weighted grades; that is, the sum
// of each grade times its weight.
double weighted_sum(std::vector<Weighted_grade> grades)
{
    double sum = 0;

    for (Weighted_grade wg : grades) {
        sum += wg.weight * wg.grade;
    }

    return sum;
}

// Computes the sum of all weights in a vector of weighted grades.
double total_weight(std::vector<Weighted_grade> grades)
{
    double sum = 0;

    for (Weighted_grade wg : grades) {
        sum += wg.weight;
    }

    return sum;
}

// Computes weighted average; exits with error message if total weight is 0.
double weighted_average(std::vector<Weighted_grade> grades)
{
    double numerator = weighted_sum(grades);
    double denominator = total_weight(grades);

    if (denominator == 0) {
        std::cerr << "No average because total weight is 0.\n";
        exit(1);
    }

    return numerator / denominator;
}

// A shortened version of main.
int short_main()
{
    std::cout << "Average: " << weighted_average(read_grades()) << '\n';
}

int main()
{
    std::vector<Weighted_grade> grades = read_grades();
    double average = weighted_average(grades);

    std::cout << "Average: " << average << '\n';
}
